@@ -5,33 +5,32 @@ from aws_lambda_powertools.logging import Logger
 from awslambdalawm.util import ObjectUtil
 from awslambdalawm.security.authz.__impl.domain import Policy, SubjectPolicyRule, ResourcePolicyRule, PolicyType, Effect
 
+_DYNAMODB_RESOURCE = boto3.resource("dynamodb")
+_DEFAULT_ENTITY_URI_FIELD_NAME = "entityUri"
+_DEFAULT_POLICY_TYPE_FIELD_NAME = "policyType"
+
 class PdpRepo:
 
-    __DYNAMODB_RESOURCE = boto3.resource("dynamodb")
-
-    __DEFAULT_ENTITY_URI_FIELD_NAME = "entityUri"
-    __DEFAULT_POLICY_TYPE_FIELD_NAME = "policyType"
-
     def __init__(self, 
             policiesTableName:str, 
-            policiesTableEntityUriFieldName:str = "entityUri",
-            policiesTablePolicyTypeFieldName:str = "policyType",
+            policiesTableEntityUriFieldName:str = _DEFAULT_ENTITY_URI_FIELD_NAME,
+            policiesTablePolicyTypeFieldName:str = _DEFAULT_POLICY_TYPE_FIELD_NAME,
             policiesKeyPrefix:str = ""):
         self.__policiesTableName = policiesTableName
         self.__policiesTableEntityUriFieldName = policiesTableEntityUriFieldName
         self.__policiesTablePolicyTypeFieldName = policiesTablePolicyTypeFieldName
         self.__policiesKeyPrefix = policiesKeyPrefix 
-        self.__policiesDdbTableResource = PdpRepo.__DYNAMODB_RESOURCE.Table(policiesTableName)
+        self.__policiesDdbTableResource = _DYNAMODB_RESOURCE.Table(policiesTableName)
         self.__logger = Logger()
 
     def savePolicy(self, policy:Policy) -> None:
         policyDict = ObjectUtil.toDict(policy)
         policyDict[self.__policiesTableEntityUriFieldName] = self.__prefixKeyFieldValue(policy.entityUri)
         policyDict[self.__policiesTablePolicyTypeFieldName] = self.__prefixKeyFieldValue(policy.policyType)
-        if self.__policiesTableEntityUriFieldName != PdpRepo.__DEFAULT_ENTITY_URI_FIELD_NAME:
-            del policyDict[PdpRepo.__DEFAULT_ENTITY_URI_FIELD_NAME]
-        if self.__policiesTablePolicyTypeFieldName != PdpRepo.__DEFAULT_POLICY_TYPE_FIELD_NAME:
-            del policyDict[PdpRepo.__DEFAULT_POLICY_TYPE_FIELD_NAME]
+        if self.__policiesTableEntityUriFieldName != _DEFAULT_ENTITY_URI_FIELD_NAME:
+            del policyDict[_DEFAULT_ENTITY_URI_FIELD_NAME]
+        if self.__policiesTablePolicyTypeFieldName != _DEFAULT_POLICY_TYPE_FIELD_NAME:
+            del policyDict[_DEFAULT_POLICY_TYPE_FIELD_NAME]
         self.__policiesDdbTableResource.put_item(
             Item = policyDict
         )
@@ -39,7 +38,7 @@ class PdpRepo:
         return policy
 
     def getPolicies(self, subjectUris:List[str], resourceUris:List[str]) -> List[Policy]:
-        policiesDict = PdpRepo.__DYNAMODB_RESOURCE.batch_get_item(
+        policiesDict = _DYNAMODB_RESOURCE.batch_get_item(
             RequestItems = {
                 self.__policiesTableName: {
                     "Keys": [
@@ -77,7 +76,7 @@ class PdpRepo:
         return self.__getPolicies(resourceUris, PolicyType.RESOURCE)
 
     def __getPolicies(self, entityUris:List[str], policyType:PolicyType) -> List[Policy]:
-        policiesDict = PdpRepo.__DYNAMODB_RESOURCE.batch_get_item(
+        policiesDict = _DYNAMODB_RESOURCE.batch_get_item(
             RequestItems = {
                 self.__policiesTableName: {
                     "Keys": [
@@ -118,8 +117,8 @@ class PdpRepo:
         return ObjectUtil.fromDict(
             dictValue = {
                 **policyDict,
-                PdpRepo.__DEFAULT_ENTITY_URI_FIELD_NAME: self.__unprefixDdbKeyFieldValue(policyDict[self.__policiesTableEntityUriFieldName]),
-                PdpRepo.__DEFAULT_POLICY_TYPE_FIELD_NAME: self.__unprefixDdbKeyFieldValue(policyDict[self.__policiesTablePolicyTypeFieldName]),
+                _DEFAULT_ENTITY_URI_FIELD_NAME: self.__unprefixDdbKeyFieldValue(policyDict[self.__policiesTableEntityUriFieldName]),
+                _DEFAULT_POLICY_TYPE_FIELD_NAME: self.__unprefixDdbKeyFieldValue(policyDict[self.__policiesTablePolicyTypeFieldName]),
             },
             objectType = Policy
         )
